@@ -22,7 +22,7 @@ $loop->SSL_listen(
 		port     => $ENV{PROTOCOL_SPDY_LISTEN_PORT} || 0,
 	},
 	SSL_npn_protocols => [
-		'spdy/3',
+		'spdy/3.1',
 		# Normally you'd also list HTTP here,
 		# but since we're only supporting SPDY
 		# in this example, we don't do that.
@@ -31,6 +31,7 @@ $loop->SSL_listen(
 	SSL_cert_file => 'certs/examples.crt',
 	SSL_key_file => 'certs/examples.key',
 	SSL_ca_path => 'certs/ProtocolSPDYCA',
+	SSL_ciphers => 'ECDHE-RSA-AES128-GCM-SHA256:ECDHE-RSA-RC4-SHA:ECDHE-RSA-AES128-SHA:RC4:HIGH:!MD5:!aNULL:!EDH',
 	on_accept => sub {
 		my $sock = shift;
 		print "Client connecting from " . join(':', $sock->peerhost, $sock->peerport) . ", we're using " . $sock->next_proto_negotiated . "\n";
