@@ -1,7 +1,5 @@
 package Protocol::SPDY::Client;
-{
-  $Protocol::SPDY::Client::VERSION = '1.000';
-}
+$Protocol::SPDY::Client::VERSION = '1.001';
 use strict;
 use warnings;
 use parent qw(Protocol::SPDY::Base);
@@ -12,7 +10,7 @@ Protocol::SPDY::Client - client-side handling for SPDY sessions
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -42,8 +40,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
