@@ -1,7 +1,5 @@
 package Protocol::SPDY::Compress;
-{
-  $Protocol::SPDY::Compress::VERSION = '1.000';
-}
+$Protocol::SPDY::Compress::VERSION = '1.001';
 use strict;
 use warnings;
 
@@ -11,7 +9,7 @@ Protocol::SPDY::Compress - handle zlib compression/decompression
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -113,8 +111,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
