@@ -1,7 +1,5 @@
 package Protocol::SPDY::Constants;
-{
-  $Protocol::SPDY::Constants::VERSION = '1.000';
-}
+$Protocol::SPDY::Constants::VERSION = '1.001';
 use strict;
 use warnings;
 use parent qw(Exporter);
@@ -12,7 +10,7 @@ Protocol::SPDY::Constants - constant definitions for the SPDY protocol
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -99,9 +97,10 @@ use constant {
 	HEADER_LENGTH => 8,
 	# The spec requires seeding our zlib instance with a specific dictionary to get
 	# better performance. Note that the dictionary varies depending on the version
-	# of the protocol we're dealing with - this is the spdy/3 dictionary:
+	# of the protocol we're dealing with - this is the spdy/3.1 dictionary:
 	ZLIB_DICTIONARY	=> join('',
 		(
+			# These are all length-prefixed strings, mostly client=>server traffic
 			map pack('N/a*', $_), qw(
 				options
 				head
@@ -160,7 +159,9 @@ use constant {
 				method
 				get
 				status
-			), "200 OK", qw(
+			),
+			"200 OK",
+			qw(
 				version
 				HTTP/1.1
 				url
@@ -170,6 +171,7 @@ use constant {
 				origin
 			)
 		),
+		# Now we have some other useful strings - these are mostly server responses, no length prefix
 		"100101201202205206300302303304305306307402405406407408409410411412413414415416417502504505",
 		"203 Non-Authoritative Information",
 		"204 No Content",
@@ -214,7 +216,7 @@ use constant {
 		7 => 'GOAWAY',
 		8 => 'HEADERS',
 		9 => 'WINDOW_UPDATE',
-		10 => 'CREDENTIAL',
+		10 => 'CREDENTIAL',   # no longer present in 3.1+
 	},
 	SETTINGS_BY_ID => {
 		# Expected upload bandwidth
@@ -287,8 +289,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
