@@ -1,7 +1,5 @@
 package Protocol::SPDY::Frame;
-{
-  $Protocol::SPDY::Frame::VERSION = '1.000';
-}
+$Protocol::SPDY::Frame::VERSION = '1.001';
 use strict;
 use warnings;
 
@@ -11,7 +9,7 @@ Protocol::SPDY::Frame - support for SPDY frames
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
@@ -235,8 +233,8 @@ Further documentation can be found in the following modules:
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
