@@ -1,7 +1,5 @@
 package Protocol::SPDY::Frame::Control;
-{
-  $Protocol::SPDY::Frame::Control::VERSION = '1.000';
-}
+$Protocol::SPDY::Frame::Control::VERSION = '1.001';
 use strict;
 use warnings;
 use parent qw(Protocol::SPDY::Frame);
@@ -12,7 +10,7 @@ Protocol::SPDY::Frame::Control - control frame subclass for the SPDY protocol
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
@@ -199,8 +197,8 @@ Further documentation can be found in the following modules:
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
