@@ -1,7 +1,5 @@
 package Protocol::SPDY::Frame::Control::SynReply;
-{
-  $Protocol::SPDY::Frame::Control::SynReply::VERSION = '1.000';
-}
+$Protocol::SPDY::Frame::Control::SynReply::VERSION = '1.001';
 use strict;
 use warnings;
 
@@ -11,7 +9,7 @@ Protocol::SPDY::Frame::Control::SynReply - obsolete, replaced by L<Protocol::SPD
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
@@ -25,8 +23,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2012. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
