@@ -1,7 +1,5 @@
 package Protocol::SPDY::Frame::Control::SynStream;
-{
-  $Protocol::SPDY::Frame::Control::SynStream::VERSION = '1.000';
-}
+$Protocol::SPDY::Frame::Control::SynStream::VERSION = '1.001';
 use strict;
 use warnings;
 
@@ -11,7 +9,7 @@ Protocol::SPDY::Frame::Control::SynStream - obsolete, replaced by L<Protocol::SP
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
@@ -23,8 +21,8 @@ See L<Protocol::SPDY> and L<Protocol::SPDY::Base>.
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2012. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
