@@ -1,7 +1,5 @@
 package Protocol::SPDY::Frame::Data;
-{
-  $Protocol::SPDY::Frame::Data::VERSION = '1.000';
-}
+$Protocol::SPDY::Frame::Data::VERSION = '1.001';
 use strict;
 use warnings;
 use parent qw(Protocol::SPDY::Frame);
@@ -12,7 +10,7 @@ Protocol::SPDY::Frame::Data - data frame support
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
@@ -115,8 +113,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
