@@ -1,7 +1,5 @@
 package Protocol::SPDY::Stream;
-{
-  $Protocol::SPDY::Stream::VERSION = '1.000';
-}
+$Protocol::SPDY::Stream::VERSION = '1.001';
 use strict;
 use warnings;
 use parent qw(Mixin::Event::Dispatch);
@@ -12,7 +10,7 @@ Protocol::SPDY::Stream - single stream representation within a L<Protocol::SPDY>
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -782,8 +780,8 @@ Further documentation can be found in the following modules:
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
