@@ -1,7 +1,5 @@
 package Protocol::SPDY::Test;
-{
-  $Protocol::SPDY::Test::VERSION = '1.000';
-}
+$Protocol::SPDY::Test::VERSION = '1.001';
 use strict;
 use warnings;
 use Protocol::SPDY::Constants ':all';
@@ -16,7 +14,7 @@ Protocol::SPDY::Test - helper functions for testing things
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -104,8 +102,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2013. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
